## GitHub Repos 

Here are the main GitHub repos used by this application (links are to the GitHub Actions page)

### CBR Repos

From the [The Cyber Boardroom ](https://github.com/the-cyber-boardroom) organisation:

 - [cbr-website-beta](https://github.com/the-cyber-boardroom/cbr-website-beta/actions)
 - [cbr-athena](https://github.com/the-cyber-boardroom/cbr-athena/actions)
 - [cbr-community](https://github.com/the-cyber-boardroom/cbr-community/actions)
 - [cbr-shared](https://github.com/the-cyber-boardroom/cbr-shared/actions)
 - [cbr-web-components](https://github.com/the-cyber-boardroom/cbr-web-components/actions)

### Osbot Repos

 - [OSBot-Fast-API](https://github.com/owasp-sbot/OSBot-Fast-API/actions/runs/10097114901)

### Others

- **hashicorp**
    - [Vault Secrets](https://portal.cloud.hashicorp.com/services/secrets?project_id=cfa2edb3-eeac-4c16-b320-9b8f9c3a6c03) - main vault
    - [CBR-CI-GitHub](https://portal.cloud.hashicorp.com/services/secrets/apps/CBR-CI-GitHub/secrets?project_id=cfa2edb3-eeac-4c16-b320-9b8f9c3a6c03) -  set CI pipeline tokens namely GIT_HUB__ACCESS_TOKEN which is used for PyPI publishing of private repos

 - **Pypi projects**
     - [cbr-content](https://pypi.org/project/cbr-content/#history)
     - [cbr-shared](https://pypi.org/project/cbr-shared/#history)